==> lincvs_1.3.2.orig.tar.gz: lincvs-1.3.2/src/UpdateOtherRevisionStdDialogImpl.cpp <==
/****************************************************************************
**
** $Id: UpdateOtherRevisionStdDialogImpl.cpp,v 1.4 2004/01/11 22:34:17 riemer Exp $
**
** Copyright (C) 2001-2004 The LinCVS development team.
**    Tilo Riemer <riemer@lincvs.org>
**    Falk Brettschneider <gigafalk@yahoo.com>
**    Frank Hemer <frank@hemer.at>
**    Wim Delvaux <wim.delvaux@chello.be>
**    Jose Hernandez <joseh@tesco.net>
**    Helmut Koll <HelmutKoll@web.de>
**    Tom Mishima <tmishima@mail.at-m.or.jp>
**    Joerg Preiss <auba@auba.de>
**    Sven Trogisch <trogisch@iapp.de>
**
**
**----------------------------------------------------------------------------
**
**----------------------------------------------------------------------------
**
** LinCVS is available under two different licenses:
**
** If LinCVS is linked against the GPLed version of Qt 
** LinCVS is released under the terms of GPL also.
**
** If LinCVS is linked against a nonGPLed version of Qt 
** LinCVS is released under the terms of the 
** LinCVS License for non-Unix platforms (LLNU)
**
**
** LinCVS License for non-Unix platforms (LLNU):
**
** Redistribution and use in binary form, without modification, 
** are permitted provided that the following conditions are met:
**
** 1. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
** 2. It is not permitted to distribute the binary package under a name
**    different than LinCVS.
** 3. The name of the authors may not be used to endorse or promote
**    products derived from this software without specific prior written
**    permission.
** 4. The source code is the creative property of the authors.
**    Extensions and development under the terms of the Gnu Public License
**    are limited to the Unix platform. Any distribution or compilation of 
**    the source code against libraries licensed other than gpl requires 
**    the written permission of the authors.
**
**
** THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR 
** IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
** ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
** GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
** NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
**
** LinCVS License for Unix platforms:
**
** This program is free software; you can redistribute it and/or modify 
** it under the terms of the GNU General Public License as published by 
** the Free Software Foundation; either version 2 of the License, or 
** (at your  option) any later version.  This program is distributed in 
** the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
** even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
** PARTICULAR PURPOSE.
**
** See the GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software Foundation,
** Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**
*****************************************************************************/

#include "config.h"

#include <qtimer.h>
#include <qmessagebox.h>
#include <qwhatsthis.h>
#include <qpushbutton.h>

#include "UpdateOtherRevisionStdDialogImpl.h"
#include "RevisionWidgetImpl.h"


UpdateOtherRevisionStdDialogImpl::UpdateOtherRevisionStdDialogImpl(bool dirOnly,
        QStringList * list, QString moduleName,
        QString caption,
	const QIconSet &whatsThisIconSet,
	QWidget * parent, const char * name, bool modal, WFlags f )
  : UpdateOtherRevisionStdDialog(parent,name,modal,f),
    m_stickyTagState(TRUE) {

  m_pWhatsThis->setIconSet(whatsThisIconSet);
  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());

  setCaption(caption);
  if (dirOnly) {
    revisionWidgetImpl->hideRevisionFrame();
  }
  revisionWidgetImpl->init(parent,list,moduleName);
  QTimer::singleShot(0,this,SLOT(updateSize()));
}

UpdateOtherRevisionStdDialogImpl::~UpdateOtherRevisionStdDialogImpl () {

}

QSize UpdateOtherRevisionStdDialogImpl::sizeHint () const {
  QSize s = UpdateOtherRevisionStdDialog::sizeHint();
  s.setWidth(UpdateOtherRevisionStdDialog::width());
  return s;
}

void UpdateOtherRevisionStdDialogImpl::updateSize() {
  adjustSize();
}

QString UpdateOtherRevisionStdDialogImpl::cvsParameter() {

  QString param = "";

  if ( useStickyTag() ) {
    if ( resetStickyTag() ) param = "-A";
    else {
      QString txt = revisionWidgetImpl->getRevision();
      if (!txt.isNull()) {
	param += "-r " + txt;
      } else {
	txt = revisionWidgetImpl->getTag();
	if (!txt.isEmpty()) param += "-r " + txt;
	txt = revisionWidgetImpl->getDateTime();
	if (!txt.isEmpty()) {
	  if (!param.isEmpty()) param += " ";
	  param += " -D \"" + txt + "\"";
	}
      }
    }
  } else {
    QString txt = revisionWidgetImpl->getRevision();
    if (!txt.isNull()) {
      param += txt;
    } else {
      txt = revisionWidgetImpl->getTag();
      if (!txt.isEmpty()) param += txt;
      txt = revisionWidgetImpl->getDateTime();
      if (!txt.isEmpty()) {
	param += ":"+txt;
      }
    }
  }

  return param;
}

bool UpdateOtherRevisionStdDialogImpl::useStickyTag() {
  return (revisionWidgetImpl->isHeadSet() || revisionWidgetImpl->isStickySet());
}

bool UpdateOtherRevisionStdDialogImpl::resetStickyTag() {
  return revisionWidgetImpl->isHeadSet();
}

void UpdateOtherRevisionStdDialogImpl::setStickyTagToggled(bool state) {
  if (!state) {
    showWarning();
  }
}

void UpdateOtherRevisionStdDialogImpl::showWarning() {
  QString txt = tr("Updating without setting sticky tags is dangerous!")+"\n"
    +tr("If no revision/tag is specified, the main trunk is assumed.")+"\n"
    +tr("To make sure all files are reverted to exactly what you want")+"\n"
    +tr("requires manually setting a regular tag and specifying this as")+"\n"
    +tr("the tag to update to.")+"\n"
    +tr("Carefully watch the cvs output and make sure")+"\n"
    +tr("cvs really does what you want.");
  QMessageBox::information(this,tr("Warning"),txt,QMessageBox::Ok);
}

void UpdateOtherRevisionStdDialogImpl::okClicked() {
  accept();
}

void UpdateOtherRevisionStdDialogImpl::enterWhatsThisMode()
{
   QWhatsThis::enterWhatsThisMode();
}

==> lincvs_1.4.0.orig.tar.gz: lincvs-1.4.0/src/UpdateOtherRevisionStdDialogImpl.cpp <==
/****************************************************************************
**
** $Id: UpdateOtherRevisionStdDialogImpl.cpp,v 1.6 2004/12/03 00:28:04 tilo Exp $
**
** Copyright (C) 2001-2004 The LinCVS development team.
**    Tilo Riemer <riemer@lincvs.org>
**    Falk Brettschneider <gigafalk@yahoo.com>
**    Frank Hemer <frank@hemer.at>
**    Wim Delvaux <wim.delvaux@chello.be>
**    Jose Hernandez <joseh@tesco.net>
**    Helmut Koll <HelmutKoll@web.de>
**    Tom Mishima <tmishima@mail.at-m.or.jp>
**    Joerg Preiss <auba@auba.de>
**    Sven Trogisch <trogisch@iapp.de>
**
**
**----------------------------------------------------------------------------
**
**----------------------------------------------------------------------------
**
** LinCVS is available under two different licenses:
**
** If LinCVS is linked against the GPLed version of Qt 
** LinCVS is released under the terms of GPL also.
**
** If LinCVS is linked against a nonGPLed version of Qt 
** LinCVS is released under the terms of the 
** LinCVS License for non-Unix platforms (LLNU)
**
**
** LinCVS License for non-Unix platforms (LLNU):
**
** Redistribution and use in binary form, without modification, 
** are permitted provided that the following conditions are met:
**
** 1. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
** 2. It is not permitted to distribute the binary package under a name
**    different than LinCVS.
** 3. The name of the authors may not be used to endorse or promote
**    products derived from this software without specific prior written
**    permission.
** 4. The source code is the creative property of the authors.
**    Extensions and development under the terms of the Gnu Public License
**    are limited to the Unix platform. Any distribution or compilation of 
**    the source code against libraries licensed other than gpl requires 
**    the written permission of the authors.
**
**
** THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR 
** IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
** WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
** ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY 
** DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL 
** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
** GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
** INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
** NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
** SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**
**
** LinCVS License for Unix platforms:
**
** This program is free software; you can redistribute it and/or modify 
** it under the terms of the GNU General Public License as published by 
** the Free Software Foundation; either version 2 of the License, or 
** (at your  option) any later version.  This program is distributed in 
** the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
** even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
** PARTICULAR PURPOSE.
**
** See the GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software Foundation,
** Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**
*****************************************************************************/

#include "config.h"

#include <qtimer.h>
#include <qmessagebox.h>
#include <qwhatsthis.h>
#include <qpushbutton.h>

#include "globals.h"
#include "UpdateOtherRevisionStdDialogImpl.h"
#include "RevisionWidgetImpl.h"

UpdateOtherRevisionStdDialogImpl::UpdateOtherRevisionStdDialogImpl(bool dirOnly,
        QStringList * list, QString moduleName,
        QString caption,
	const QIconSet &whatsThisIconSet,
	QWidget * parent, const char * name, bool modal, WFlags f )
//  : UpdateOtherRevisionStdDialog(LookAndFeel::g_b0AsParent ? 0 : parent,name,modal,f),
  : UpdateOtherRevisionStdDialog(modal ? parent : (LookAndFeel::g_b0AsParent ? 0 : parent),
				 name,modal,f),
    m_stickyTagState(TRUE) {

  m_pWhatsThis->setIconSet(whatsThisIconSet);
  m_pWhatsThis->setMaximumWidth(m_pWhatsThis->height());

  setCaption(caption);
  if (dirOnly) {
    revisionWidgetImpl->hideRevisionFrame();
  }
  revisionWidgetImpl->init(parent,list,moduleName);
  QTimer::singleShot(0,this,SLOT(updateSize()));
}

UpdateOtherRevisionStdDialogImpl::~UpdateOtherRevisionStdDialogImpl () {

}

QSize UpdateOtherRevisionStdDialogImpl::sizeHint () const {
  QSize s = UpdateOtherRevisionStdDialog::sizeHint();
  s.setWidth(UpdateOtherRevisionStdDialog::width());
  return s;
}

void UpdateOtherRevisionStdDialogImpl::updateSize() {
  adjustSize();
}

QString UpdateOtherRevisionStdDialogImpl::cvsParameter() {

  QString param = "";

  if ( useStickyTag() ) {
    if ( resetStickyTag() ) param = "-A";
    else {
      QString txt = revisionWidgetImpl->getRevision();
      if (!txt.isNull()) {
	param += "-r " + txt;
      } else {
	txt = revisionWidgetImpl->getTag();
	if (!txt.isEmpty()) param += "-r " + txt;
	txt = revisionWidgetImpl->getDateTime();
	if (!txt.isEmpty()) {
	  if (!param.isEmpty()) param += " ";
	  param += " -D \"" + txt + "\"";
	}
      }
    }
  } else {
    QString txt = revisionWidgetImpl->getRevision();
    if (!txt.isNull()) {
      param += txt;
    } else {
      txt = revisionWidgetImpl->getTag();
      if (!txt.isEmpty()) param += txt;
      txt = revisionWidgetImpl->getDateTime();
      if (!txt.isEmpty()) {
	param += ":"+txt;
      }
    }
  }

  return param;
}

bool UpdateOtherRevisionStdDialogImpl::useStickyTag() {
  return (revisionWidgetImpl->isHeadSet() || revisionWidgetImpl->isStickySet());
}

bool UpdateOtherRevisionStdDialogImpl::resetStickyTag() {
  return revisionWidgetImpl->isHeadSet();
}

void UpdateOtherRevisionStdDialogImpl::setStickyTagToggled(bool state) {
  if (!state) {
    showWarning();
  }
}

void UpdateOtherRevisionStdDialogImpl::showWarning() {
  QString txt = tr("Updating without setting sticky tags is dangerous!")+"\n"
    +tr("If no revision/tag is specified, the main trunk is assumed.")+"\n"
    +tr("To make sure all files are reverted to exactly what you want")+"\n"
    +tr("requires manually setting a regular tag and specifying this as")+"\n"
    +tr("the tag to update to.")+"\n"
    +tr("Carefully watch the cvs output and make sure")+"\n"
    +tr("cvs really does what you want.");
  QMessageBox::information(this,tr("Warning"),txt,QMessageBox::Ok);
}

void UpdateOtherRevisionStdDialogImpl::okClicked() {
  accept();
}

void UpdateOtherRevisionStdDialogImpl::enterWhatsThisMode()
{
   QWhatsThis::enterWhatsThisMode();
}
